@@ -1,7 +1,7 @@
 # coding=utf-8
 # -*- coding:utf-8 -*-
 
-from ..util import client, ossclient, formater, list2table, result_cache, dag
+from ..util import client, oss_client, formater, list2table, result_cache, dag, util
 from terminal import bold, magenta, gray, blue, green, red, yellow, confirm
 from oss2.exceptions import NoSuchKey,NoSuchBucket
 PROGRESS_LEN = 50
@@ -113,8 +113,15 @@ def getJobDetail(jobId, descOnly):
 
     # dag
     print('%s' % bold(magenta('DAG:')))
-    dag.draw(desc.get('DAG').get('Dependencies'))
 
+    deps = get_task_deps(desc.get('DAG'))
+
+    matric = dag.sortIndex(deps)
+
+    dag.draw(deps, matric)
+
+
+    # task list
     tasks = client.list_tasks(jobId)
 
     arr = formater.items2arr(tasks.get('Items'))
@@ -126,7 +133,9 @@ def getJobDetail(jobId, descOnly):
         item['Counts'] = calc_metric_count(item['InstanceMetrics'])
         task_desc = desc.DAG.Tasks[item['TaskName']]
 
-        item['Cluster'] = get_cluster_str(task_desc)
+        item['Cluster'] = util.get_cluster_str(task_desc)
+
+    arr = sort_task_by_deps(arr, matric)
 
     # cache
     result_cache.save(arr, 'TaskName', 'tasks')
@@ -150,7 +159,7 @@ def getTaskDetail(jobId, taskName):
     taskInfo['Counts'] = calc_metric_count(taskInfo['InstanceMetrics'])
     taskDesc = jobDesc.DAG.Tasks[taskInfo['TaskName']]
 
-    taskInfo['Cluster'] = get_cluster_str(taskDesc)
+    taskInfo['Cluster'] = util.get_cluster_str(taskDesc)
 
     arr = formater.format_date_in_arr([taskInfo], [ 'StartTime', 'EndTime'])
 
@@ -254,24 +263,22 @@ def getInstanceDetail(jobId, taskName, instanceId):
 def showLog(osspath, jobId, taskName, instanceId, logType):
 
     osspath = formater.fix_log_path(osspath ,jobId,taskName, instanceId, logType)
-    content = ossclient.get_content(osspath)
+    content = oss_client.get_data(osspath)
 
     print('%s' % bold(magenta('Log Content:')))
     if isinstance(content, bytes):
-        print(str(content.decode('utf8')))
-    else:
-        print(content)
+        content = str(content.decode('utf8'))
 
-def get_cluster_str(task_desc):
-    if task_desc.get('AutoCluster'):
-        return "img=%s:type=%s" % (task_desc['AutoCluster']['ECSImageId'],task_desc['AutoCluster']['InstanceType'])
+    if logType == 'stdout':
+        print(green(content))
     else:
-        return task_desc.get('ClusterId')
+        print(red(content))
+
 
 def calc_metric_count(metric):
     g = metric
-    total = g['RunningCount'] + g['WaitingCount'] + g['FinishedCount'] + g['StoppedCount']
-    count = g['FinishedCount'] + g['StoppedCount']
+    total = g['RunningCount'] + g['WaitingCount'] + g['FinishedCount'] + g['StoppedCount']+g['FailedCount']
+    count = g['FinishedCount'] + g['FailedCount']
 
     return '%s / %s' % (count, total)
 
@@ -286,7 +293,31 @@ def sort_job_list(arr):
             finished_arr.append(n)
 
     finished_arr = formater.order_by(finished_arr, ['CreationTime'], True)
-    unfinished_arr = formater.order_by(unfinished_arr, ['StartTime'], True)
+    unfinished_arr = formater.order_by(unfinished_arr, ['StartTime','CreationTime'], True)
 
     return unfinished_arr + finished_arr
 
+def sort_task_by_deps(arr, matric):
+    m = {}
+    for n in arr:
+        m[n['TaskName']]=n
+
+    t=[]
+    for items in matric:
+        for taskname in items:
+            t.append(m[taskname])
+    return t
+
+def get_task_deps(dag):
+    deps = dag.get('Dependencies') or {}
+    tasks = dag.get('Tasks')
+
+    m = {}
+    for k in tasks:
+        m[k] = []
+
+    for k in m:
+        if not deps.get(k):
+            deps[k] = []
+
+    return deps
