@@ -13,7 +13,7 @@ from ..const import IMG_ID,INS_TYPE,CMD
 
 DEFAULT_CLUSTER = "img=%s:type=%s" % (IMG_ID,INS_TYPE)
 
-def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env=None, mount=None):
+def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env=None, read_mount={}, write_mount={}, mount=None):
 
     pre_oss_path = config.get_oss_path()
 
@@ -33,8 +33,15 @@ def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env
         job_desc['DAG']['Tasks']['cli-task']['Parameters']['Command']['EnvVars']=env
 
     if mount:
-        job_desc['DAG']['Tasks']['cli-task']['InputMapping']=mount
-        job_desc['DAG']['Tasks']['cli-task']['OutputMapping']=reverse_kv(mount)
+        for k,v in mount.items():
+            read_mount[k]=v
+            write_mount[k]=v
+
+    if read_mount:
+        job_desc['DAG']['Tasks']['cli-task']['InputMapping']=read_mount
+    if write_mount:
+        job_desc['DAG']['Tasks']['cli-task']['OutputMapping']=reverse_kv(write_mount)
+
 
     rand = gen_rand_id()
 
@@ -49,6 +56,8 @@ def submit(cmd, cluster=DEFAULT_CLUSTER, timeout=172800, nodes=1, pack=None, env
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['StdoutRedirectPath'] = '%s%s/logs/' % (pre_oss_path,rand)
     job_desc['DAG']['Tasks']['cli-task']['Parameters']['StderrRedirectPath'] = '%s%s/logs/' % (pre_oss_path,rand)
 
+    #print(job_desc)
+
     result = client.create_job(job_desc)
 
     if result.StatusCode==201:
