@@ -345,10 +345,15 @@ cmd_submit_job.option("-n, --nodes [machine_number]",
 cmd_submit_job.option("-e, --env [kv_pairs]",
                       MSG['submit']['option']['env'],
                       resolve=job_submit.trans_env)
+cmd_submit_job.option("-r, --read_mount [kv_pairs]",
+                       MSG['submit']['option']['read_mount'],
+                      resolve=job_submit.trans_mount)
+cmd_submit_job.option("-w, --write_mount [kv_pairs]",
+                       MSG['submit']['option']['write_mount'],
+                      resolve=job_submit.trans_mount)
 cmd_submit_job.option("-m, --mount [kv_pairs]",
                        MSG['submit']['option']['mount'],
                       resolve=job_submit.trans_mount)
-
 program.action(cmd_submit_job)
 
 
