@@ -103,8 +103,9 @@ def getJSON():
                 'timeout': "job would failed if it had expired, default: 172800(2 days)",
                 'nodes': "the number of machines you needed to run the program, default: 1",
                 'env': "set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
-                'mount': "mount a oss path to local file system, kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<div_path2>...], example: oss://bucket/key:/home/admin/ossdir "
-
+                'read_mount': "mount a oss path to local file system in read-only mode, kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...], example: oss://bucket/key:/home/admin/ossdir ",
+                'write_mount': "mount a oss path to local file system in writable mode(files in the mounted folder will be upload to oss_path after the task is finished), kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...], example: oss://bucket/key:/home/admin/ossdir ",
+                'mount': "mount a oss path to local file system in read/write mode, kv-pairs, multi-supported, format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...], example: oss://bucket/key:/home/admin/ossdir "
             }
         },
         'project': {
@@ -134,6 +135,18 @@ def getJSON():
             },
             'status': {
                 'description': 'show project status.'
+            },
+            'add_task': {
+                'description': 'add a task',
+                'detail': "add a task node into job.json, and create a promgram(python) file in src folder.",
+                'option': {
+                    'cluster': """should be a cluster_id, or an auto_cluster string.
+                                  default value is an auto_cluster string: img=%s:type=%s.
+                                  you can use a exists cluster(type '%s c' for more cluster id),
+                                  or use auto cluster, format: img=<imageId>:type=<instanceType> (instanceType default: %s, type '%s it' for more instanceType). """,
+
+                    'docker': 'docker image name, must tag with prefix:"localhost:5000/", type "docker images" for more'
+                }
             }
         },
         'oss': {
