@@ -98,13 +98,15 @@ def getJSON():
                 'cluster': """可选,可以使一个集群ID或者AutoCluster配置字符串.
                                  默认是一个AutoCluster配置字符串: img=%s:type=%s.
                                  你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
-                                 或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: %s, type '%s it' 可以看到更多instanceType). """ % (
-                IMG_ID, INS_TYPE, CMD, INS_TYPE, CMD),
+                                 或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """ % (
+                IMG_ID, INS_TYPE, CMD, CMD),
                 'pack': "可选,打包指定目录下的文件,并上传到OSS, 如果没有指定这个选项则不打包不上传",
                 'timeout': "可选,超时时间(如果实例运行时间超时则失败), 默认: 172800(单位秒,表示2天)",
                 'nodes': "可选,需要运行程序的机器数, 默认: 1",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
-                'mount': "可选,挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<div_path2>...],如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录"
+                'read_mount': "可选,只读模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录",
+                'write_mount': "可选,可写模式挂载配置(任务结束后写到本地目录的文件会被上传到相应的oss_path下), 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录",
+                'mount': "可选,读写模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录",
 
             }
         },
@@ -127,7 +129,7 @@ def getJSON():
                     'cluster': """可以使一个集群ID或者AutoCluster配置字符串.
                               默认是一个AutoCluster配置字符串: img=%s:type=%s.
                               你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
-                              或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: %s, type '%s it' 可以看到更多instanceType). """
+                              或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """ % (IMG_ID, INS_TYPE, CMD, CMD)
                 }
             },
             'submit':{
@@ -135,6 +137,18 @@ def getJSON():
             },
             'status': {
                 'description': '显示工程状态.'
+            },
+            'add_task': {
+                'description': '增加一个任务',
+                'detail': "在job.json中增加一个任务节点, 并且在src目录创建一个程序文件(目前只支持python)",
+                'option': {
+                    'cluster': """可以使一个集群ID或者AutoCluster配置字符串.
+                                  默认是一个AutoCluster配置字符串: img=%s:type=%s.
+                                  你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
+                                  或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType> (运行这个: '%s it' 可以看到更多instanceType). """ % (IMG_ID, INS_TYPE, CMD, CMD),
+
+                    'docker': 'Docker镜像名, 需要以前缀"localhost:5000/"打tag'
+                }
             }
         },
         'oss': {
